@@ -52,6 +52,7 @@ func redoDirClean(root, what string) error {
 	if err != nil {
 		return err
 	}
+	defer dir.Close()
 	for {
 		fis, err := dir.Readdir(1 << 10)
 		if err != nil {
@@ -88,7 +89,7 @@ func redoDirClean(root, what string) error {
 			}
 		}
 	}
-	return dir.Close()
+	return nil
 }
 
 func cleanupWalker(root, what string) error {
@@ -147,5 +148,5 @@ func cleanupWalker(root, what string) error {
 			}
 		}
 	}
-	return dir.Close()
+	return nil
 }
