@@ -188,7 +188,7 @@ func isOOD(cwd, tgtOrig string, level int, seen map[string]struct{}) (bool, erro
 			}
 			tracef(CDebug, "ood: %s%s -> %s: same hash", indent, tgtOrig, dep)
 		}
-		fd.Close() // optimization not to hold it for long
+		fd.Close()
 
 		if dep == tgt {
 			tracef(CDebug, "ood: %s%s -> %s: same target", indent, tgtOrig, dep)
