@@ -21,6 +21,8 @@ package main
 
 import (
 	"bufio"
+	"crypto/rand"
+	"encoding/hex"
 	"errors"
 	"flag"
 	"fmt"
@@ -402,7 +404,11 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 	cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", EnvDirPrefix, dirPrefix))
 	cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", EnvBuildUUID, BuildUUID))
 
-	childStderrPrefix := tempsuffix()
+	childStderrPrefixRaw := make([]byte, 8)
+	if _, err = io.ReadFull(rand.Reader, childStderrPrefixRaw); err != nil {
+		panic(err)
+	}
+	childStderrPrefix := hex.EncodeToString(childStderrPrefixRaw)
 	cmd.Env = append(cmd.Env, fmt.Sprintf(
 		"%s=%s", EnvStderrPrefix, childStderrPrefix,
 	))
