@@ -54,6 +54,7 @@ func targetsCollect(root string, tgts map[string]struct{}) error {
 					return err
 				}
 				redoFis, err := redoDir.Readdir(0)
+				redoDir.Close()
 				if err != nil {
 					return err
 				}
@@ -64,7 +65,6 @@ func targetsCollect(root string, tgts map[string]struct{}) error {
 						tgts[name[:len(name)-len(DepSuffix)]] = struct{}{}
 					}
 				}
-				redoDir.Close()
 			} else {
 				if err = targetsCollect(pth, tgts); err != nil {
 					return err
@@ -72,7 +72,7 @@ func targetsCollect(root string, tgts map[string]struct{}) error {
 			}
 		}
 	}
-	return dir.Close()
+	return nil
 }
 
 func targetsWalker(tgts []string) ([]string, error) {
